find_env_file

Function find_env_file 

pub fn find_env_file(base_config: &Path, env: &str) -> Option<PathBuf>
Find a sibling overlay for env next to base_config.

base_config should be the resolved path to the base fdl.yml (not a directory). Returns Some(path) if fdl.<env>.<ext> exists for any supported extension, None otherwise.