exec_script

Function exec_script 

pub fn exec_script(
    command: &str,
    append: Option<&str>,
    user_args: &[String],
    docker_service: Option<&str>,
    cwd: &Path,
) -> ExitCode
Run an inline run: script, optionally wrapped in Docker.

user_args (from CLI tokens after --) are POSIX-quoted and spliced between command and append, so a script like cargo test live with append: -- --nocapture --ignored still receives its libtest flags after a user-supplied -p flodl-hf.