print_run_help

Function print_run_help 

pub fn print_run_help(
    name: &str,
    description: Option<&str>,
    run: &str,
    docker: Option<&str>,
)
Print help for a run:-kind command. Shows the inline script that will execute and the Docker service (if any). run: commands do not forward argv, so there are no flags or positionals to document.